==> ejc-ztpczr-impl-3.0.0-20230530.024828-2-sources.jar: com/ejianc/business/ztpczr/controller/SystemController.java <==
package com.ejianc.business.ztpczr.controller;

import com.ejianc.business.ztpczr.bean.DcFileTypeQuery;
import com.ejianc.business.ztpczr.cores.utils.ToolUtil;
import com.ejianc.business.ztpczr.service.ISystemService;
import com.ejianc.business.ztpczr.bean.SystemEntity;
import com.ejianc.business.ztpczr.bean.SystemRtEntity;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ResultAsTree;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * CVAR
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("pubVarConfig")
public class SystemController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISystemService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * 简版新参照
     * @param tableName
     * @return
     */
    @RequestMapping(value = "/queryByTableName", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Map<String,List<Map>>> queryListByAttribute(@RequestParam String tableName) {

        QueryParam param = new QueryParam();

        List<SystemEntity> systemEntities = service.selectByTableName(tableName);

        if (systemEntities == null||systemEntities.size() != 3){
            return CommonResponse.success("该表没有设置参照！tableName:"+tableName);
        }

        List<SystemRtEntity> systemRtEntityList = service.selectByCode(systemEntities);

        List<Map> filterEntityList = new ArrayList<>();

        systemRtEntityList.stream().forEach(e -> {
            Map entityMap = new HashMap();
            entityMap.put("code", e.getCode());
            entityMap.put("name", e.getName());
            entityMap.put("id", e.getId());
            filterEntityList.add(entityMap);
        });



        //业务需要 包装对象
        Map data = new HashMap<>();
        data.put("data",filterEntityList);
        return CommonResponse.success("查询列表数据成功！", data);
    }



    /**
     * 异步树----文件类型
     *
     * @param condition
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/dcFileTypeQueryTree", method = RequestMethod.GET)
    @ResponseBody
    public List<Map<String, Object>> dcFileTypeQueryTree(@RequestParam(required=false) String condition,
                                                              @RequestParam(required=false) Long pid,
                                                         @RequestParam(required = false) String searchText) {

        Map<String,Object> params = new HashMap<>();
        params.put("belongOrgId",sessionManager.getUserContext().getOrgId());
        if (ToolUtil.isEmpty(pid)){
            params.put("pid",1474197986685751299L);
        } else {
            params.put("pid",pid);
        }
        List<Long> inIds = null;
        List<Long> notInIds = null;
        if (ToolUtil.isNotEmpty(condition)){
            if (condition.startsWith("inIds")){
                String substring = condition.substring("inIds".length());
                inIds = getIds(substring);
            }
            if (condition.startsWith("notInIds")){
                String substring = condition.substring("notInIds".length());
                notInIds = getIds(substring);
            }
        }
        params.put("inIds",inIds);
        params.put("notInIds",notInIds);
        List<DcFileTypeQuery> dataList = service.dcFileTypeQuery(params);
        List<Map> map = BeanMapper.mapList(dataList, Map.class);
        return ResultAsTree.createTreeData(map);

    }


    public static List<Long> getIds(String ids){
        if (ToolUtil.isEmpty(ids)){
            return null;
        }else {
            List<Long> collect = Arrays.stream(ids.split(",")).map(Long::parseLong).collect(Collectors.toList());
            return collect;
        }
    }

//    public static void main(String[] args) {
//
//        String test1 = "inIds333,111,111,111";
//        String test2 = "notInIds222,222,222,222";
//        String substring = test2.substring("notInIds".length());
//        getIds(substring).stream().forEach(System.out::println);
//
//    }

}

==> ejc-ztpczr-impl-3.0.0-20230607.011903-13-sources.jar: com/ejianc/business/ztpczr/controller/SystemController.java <==
package com.ejianc.business.ztpczr.controller;

import com.ejianc.business.ztpczr.bean.DcFileTypeQuery;
import com.ejianc.business.ztpczr.cores.utils.ToolUtil;
import com.ejianc.business.ztpczr.service.ISystemService;
import com.ejianc.business.ztpczr.bean.SystemEntity;
import com.ejianc.business.ztpczr.bean.SystemRtEntity;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ResultAsTree;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * CVAR
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("pubVarConfig")
public class SystemController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISystemService service;

    @Autowired
    private SessionManager sessionManager;
    /**
     * 简版新参照
     * @param tableName
     * @return
     */
    @RequestMapping(value = "/queryListByAttributeTbKey", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Map<Object,Map>> queryListByAttributeTbKey(@RequestParam String tableName,@RequestParam String keyType) {

        ServletRequestAttributes requestAttributes = ServletRequestAttributes.class.
                cast(RequestContextHolder.getRequestAttributes());
        HttpServletRequest contextRequest = requestAttributes.getRequest();

        QueryParam param = new QueryParam();

        List<SystemEntity> systemEntities = service.selectByTableName(tableName);

        if (systemEntities == null||systemEntities.size() != 3){
            return CommonResponse.success("该表没有设置参照！tableName:"+tableName);
        }

        List<SystemRtEntity> systemRtEntityList = service.selectByCode(systemEntities);

        Map<Object,Map> filterEntityList = new HashMap<>();

        systemRtEntityList.stream().forEach(e -> {
            Map entityMap = new HashMap();
            entityMap.put("code", e.getCode());
            entityMap.put("name", e.getName());
            entityMap.put("id", e.getId());
            Object key = e.getId();
            if ("code".equals(keyType)){
                key = e.getCode();
            }else if ("name".equals(keyType)){
                key = e.getName();
            }
            filterEntityList.put(key,entityMap);
        });
        return CommonResponse.success("查询列表数据成功！", filterEntityList);
    }

    /**
     * 简版新参照
     * @param tableName
     * @return
     */
    @RequestMapping(value = "/queryListByAttributeTb", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Map<String,List<Map>>> queryListByAttributeTb(@RequestParam String tableName) {

        ServletRequestAttributes requestAttributes = ServletRequestAttributes.class.
                cast(RequestContextHolder.getRequestAttributes());
        HttpServletRequest contextRequest = requestAttributes.getRequest();

        QueryParam param = new QueryParam();

        List<SystemEntity> systemEntities = service.selectByTableName(tableName);

        if (systemEntities == null||systemEntities.size() != 3){
            return CommonResponse.success("该表没有设置参照！tableName:"+tableName);
        }

        List<SystemRtEntity> systemRtEntityList = service.selectByCode(systemEntities);

        List<Map> filterEntityList = new ArrayList<>();

        systemRtEntityList.stream().forEach(e -> {
            Map entityMap = new HashMap();
            entityMap.put("code", e.getCode());
            entityMap.put("name", e.getName());
            entityMap.put("id", e.getId());
            filterEntityList.add(entityMap);
        });



        //业务需要 包装对象
        Map data = new HashMap<>();

        data.put("data",filterEntityList);

        return CommonResponse.success("查询列表数据成功！", data);
    }



    /**
     * 异步树----文件类型
     *
     * @param condition
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/dcFileTypeQueryTree", method = RequestMethod.GET)
    @ResponseBody
    public List<Map<String, Object>> dcFileTypeQueryTree(@RequestParam(required=false) String condition,
                                                              @RequestParam(required=false) Long pid,
                                                         @RequestParam(required = false) String searchText) {

        Map<String,Object> params = new HashMap<>();
        params.put("belongOrgId",sessionManager.getUserContext().getOrgId());
        if (ToolUtil.isEmpty(pid)){
            params.put("pid",1474197986685751299L);
        } else {
            params.put("pid",pid);
        }
        List<Long> inIds = null;
        List<Long> notInIds = null;
        if (ToolUtil.isNotEmpty(condition)){
            if (condition.startsWith("inIds")){
                String substring = condition.substring("inIds".length());
                inIds = getIds(substring);
            }
            if (condition.startsWith("notInIds")){
                String substring = condition.substring("notInIds".length());
                notInIds = getIds(substring);
            }
        }
        params.put("inIds",inIds);
        params.put("notInIds",notInIds);
        List<DcFileTypeQuery> dataList = service.dcFileTypeQuery(params);
        List<Map> map = BeanMapper.mapList(dataList, Map.class);
        return ResultAsTree.createTreeData(map);

    }


    public static List<Long> getIds(String ids){
        if (ToolUtil.isEmpty(ids)){
            return null;
        }else {
            List<Long> collect = Arrays.stream(ids.split(",")).map(Long::parseLong).collect(Collectors.toList());
            return collect;
        }
    }

//    public static void main(String[] args) {
//
//        String test1 = "inIds333,111,111,111";
//        String test2 = "notInIds222,222,222,222";
//        String substring = test2.substring("notInIds".length());
//        getIds(substring).stream().forEach(System.out::println);
//
//    }

}
